@@ -1,4 +1,3 @@
-from backstage.venue import Venue, new_venue
+from backstage.venue import Venue
 from backstage.act.act import Act
-
 from backstage.site import Site
