@@ -24,6 +24,20 @@ class Act():
         sys.path = syspath
         self.settings = settings
 
+    def uwsgi_linker(self, linkmode='link'):
+        linkmodes = ['link', 'unlink', 'relink']
+        inifile = os.path.abspath(os.path.join(self.acthome,'uwsgi.ini'))
+        linkfile = UWSGI_VASSALS
+        if linkmode not in linkmodes:
+            return 'Usage: uwsgi_linker <%s>' % (linkmodes)
+        if linkmode == 'link':
+            pass
+        elif linkmode == 'unlink':
+            pass
+        elif linkmode == 'relink'
+
+    def uwsgi_unlink(self):
+
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
     if isinstance(venue, str):
